component_state

Function component_state 

pub fn component_state(id: &Ustr) -> Result<ComponentState>
Returns the state of a component in the global registry.

Errors

  • Returns an error if the component is not found.
  • Returns an error if the component is already borrowed.