pub fn stop_component(id: &Ustr) -> Result<()>Expand description
Safely calls stop() on a component in the global registry.
Errors
- Returns an error if the component is not found.
- Returns an error if the component is already borrowed.
- Returns an error if
stop()fails.